==> linuxconf-1.20.src.tar.gz: linuxconf-1.20/modules/isapnpconf/isapnpconf.pm <==
/* isapnpconf.cc 04/07/2000 17.27.14 */
PUBLIC MODULE_isapnpconf::MODULE_isapnpconf (void);
PUBLIC void MODULE_isapnpconf::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_isapnpconf::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_isapnpconf::dohtml (const char *key);
PUBLIC void MODULE_isapnpconf::usage (SSTRINGS&tb);
PUBLIC int MODULE_isapnpconf::execmain (int argc, char *argv[]);
PUBLIC void MODULE_isapnpconf::isapnpconf_start (void);
PUBLIC int MODULE_isapnpconf::detec (SSTRINGS&isapnp, SSTRINGS&log);
PUBLIC int MODULE_isapnpconf::add (SSTRINGS&isapnp);
PUBLIC int MODULE_isapnpconf::isapnpconf_edit (void);
/* _dict.cc 04/07/2000 13.58.32 */
/* isapnpconf_file.cc 04/07/2000 13.58.32 */
PUBLIC int MODULE_isapnpconf::backup_file (void);
PUBLIC int MODULE_isapnpconf::rewrite_isapnp (void);
PUBLIC int MODULE_isapnpconf::read_file (SSTRINGS&ss);
PUBLIC int MODULE_isapnpconf::save_file (SSTRINGS&ss);
/* isapnpconf_parser.cc 04/07/2000 13.58.32 */
PUBLIC int MODULE_isapnpconf::create_struct (SSTRINGS&isapnp);
PUBLIC int MODULE_isapnpconf::read_a_setting (int &line,
	 settings *tset,
	 SSTRINGS&ss);
PUBLIC void MODULE_isapnpconf::read_card_header (int &line,
	 struct pcard *tcard,
	 SSTRINGS&ss);
PUBLIC void MODULE_isapnpconf::read_configure (struct pcard *tcard,
	 struct configure *dat,
	 int &line,
	 SSTRINGS&ss);
PUBLIC void MODULE_isapnpconf::read_end_configure (struct configure *dat,
	 int &line,
	 SSTRINGS&ss);
PUBLIC void MODULE_isapnpconf::read_file_header (const char *cont);
/* isapnpconf_struct.cc 13/07/2000 22.43.18 */
PUBLIC int MODULE_isapnpconf::get_n_dma (struct settings *s);
PUBLIC int MODULE_isapnpconf::get_n_irq (struct settings *s);
PUBLIC int MODULE_isapnpconf::get_n_io (struct settings *s);
PUBLIC int MODULE_isapnpconf::get_n_settings (struct configure *c);
PUBLIC int MODULE_isapnpconf::get_n_configure (struct pcard *c);
PUBLIC int MODULE_isapnpconf::get_n_card (void);
PUBLIC struct s_dma *MODULE_isapnpconf::get_dma (struct settings *s,
	 int n);
PUBLIC struct s_irq *MODULE_isapnpconf::get_irq (struct settings *s,
	 int n);
PUBLIC struct s_io *MODULE_isapnpconf::get_io (struct settings *s,
	 int n);
PUBLIC struct settings *MODULE_isapnpconf::get_setting (struct configure *c,
	 int n);
PUBLIC struct configure *MODULE_isapnpconf::get_configure (struct pcard *c,
	 int n);
PUBLIC struct pcard *MODULE_isapnpconf::get_card (int n);
PUBLIC void MODULE_isapnpconf::clean_struct (void);
PUBLIC void MODULE_isapnpconf::print_struct (void);
PUBLIC void MODULE_isapnpconf::print_all_struct (void);
PUBLIC struct pcard *MODULE_isapnpconf::add_card (void);
PUBLIC struct configure *MODULE_isapnpconf::add_configure (void);
PUBLIC struct settings *MODULE_isapnpconf::add_setting (void);
PUBLIC struct s_io *MODULE_isapnpconf::add_io (void);
PUBLIC struct s_irq *MODULE_isapnpconf::add_irq (void);
PUBLIC struct s_dma *MODULE_isapnpconf::add_dma (void);

==> linuxconf-1.21.src.tar.gz: linuxconf-1.21/modules/isapnpconf/isapnpconf.pm <==
/* _dict.cc 04/07/2000 13.58.32 */
/* isapnpconf.cc 28/08/2000 18.12.58 */
PUBLIC MODULE_isapnpconf::MODULE_isapnpconf (void);
PUBLIC void MODULE_isapnpconf::setmenu (DIALOG&dia,
	 MENU_CONTEXT context);
PUBLIC int MODULE_isapnpconf::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_isapnpconf::dohtml (const char *key);
PUBLIC void MODULE_isapnpconf::usage (SSTRINGS&tb);
PUBLIC int MODULE_isapnpconf::execmain (int argc,
	 char *argv[],
	 bool);
PUBLIC void MODULE_isapnpconf::isapnpconf_start (void);
PUBLIC int MODULE_isapnpconf::detec (SSTRINGS&isapnp, SSTRINGS&log);
PUBLIC int MODULE_isapnpconf::add (SSTRINGS&isapnp);
PUBLIC int MODULE_isapnpconf::isapnpconf_edit (void);
/* isapnpconf_file.cc 07/08/2000 11.25.22 */
PUBLIC int MODULE_isapnpconf::backup_file (void);
PUBLIC int MODULE_isapnpconf::rewrite_isapnp (void);
PUBLIC int MODULE_isapnpconf::read_file (SSTRINGS&ss);
PUBLIC int MODULE_isapnpconf::save_file (SSTRINGS&ss);
/* isapnpconf_parser.cc 13/07/2000 22.44.10 */
PUBLIC int MODULE_isapnpconf::create_struct (SSTRINGS&isapnp);
PUBLIC int MODULE_isapnpconf::read_a_setting (int &line,
	 settings *tset,
	 SSTRINGS&ss);
PUBLIC void MODULE_isapnpconf::read_card_header (int &line,
	 struct pcard *tcard,
	 SSTRINGS&ss);
PUBLIC void MODULE_isapnpconf::read_configure (struct pcard *tcard,
	 struct configure *dat,
	 int &line,
	 SSTRINGS&ss);
PUBLIC void MODULE_isapnpconf::read_end_configure (struct configure *dat,
	 int &line,
	 SSTRINGS&ss);
PUBLIC void MODULE_isapnpconf::read_file_header (const char *cont);
/* isapnpconf_struct.cc 13/07/2000 22.43.18 */
PUBLIC int MODULE_isapnpconf::get_n_dma (struct settings *s);
PUBLIC int MODULE_isapnpconf::get_n_irq (struct settings *s);
PUBLIC int MODULE_isapnpconf::get_n_io (struct settings *s);
PUBLIC int MODULE_isapnpconf::get_n_settings (struct configure *c);
PUBLIC int MODULE_isapnpconf::get_n_configure (struct pcard *c);
PUBLIC int MODULE_isapnpconf::get_n_card (void);
PUBLIC struct s_dma *MODULE_isapnpconf::get_dma (struct settings *s,
	 int n);
PUBLIC struct s_irq *MODULE_isapnpconf::get_irq (struct settings *s,
	 int n);
PUBLIC struct s_io *MODULE_isapnpconf::get_io (struct settings *s,
	 int n);
PUBLIC struct settings *MODULE_isapnpconf::get_setting (struct configure *c,
	 int n);
PUBLIC struct configure *MODULE_isapnpconf::get_configure (struct pcard *c,
	 int n);
PUBLIC struct pcard *MODULE_isapnpconf::get_card (int n);
PUBLIC void MODULE_isapnpconf::clean_struct (void);
PUBLIC void MODULE_isapnpconf::print_struct (void);
PUBLIC void MODULE_isapnpconf::print_all_struct (void);
PUBLIC struct pcard *MODULE_isapnpconf::add_card (void);
PUBLIC struct configure *MODULE_isapnpconf::add_configure (void);
PUBLIC struct settings *MODULE_isapnpconf::add_setting (void);
PUBLIC struct s_io *MODULE_isapnpconf::add_io (void);
PUBLIC struct s_irq *MODULE_isapnpconf::add_irq (void);
PUBLIC struct s_dma *MODULE_isapnpconf::add_dma (void);
